@@ -940,6 +940,19 @@ atspi_init (void)
   return 0;
 }
 
+/**
+ * atspi_is_initialized:
+ *
+ * Indicates whether AT-SPI has been initialized.
+ *
+ * Returns: %True if initialized; %False otherwise.
+ */
+gboolean
+atspi_is_initialized ()
+{
+  return atspi_inited;
+}
+
 /**
  * atspi_event_main:
  *
